@@ -10,7 +10,7 @@ use Raisin::Request;
 use Raisin::Response;
 use Raisin::Routes;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub new {
     my ($class, %args) = @_;
@@ -251,8 +251,8 @@ Raisin - REST-like API micro-framework for Perl.
     namespace '/user' => sub {
         get params => [
             #required/optional => [name, type, default, regex]
-            optional => ['start', $Raisin::Types::Integer, 0],
-            optional => ['count', $Raisin::Types::Integer, 10],
+            optional => ['start', 'Raisin::Types::Integer', 0],
+            optional => ['count', 'Raisin::Types::Integer', 10],
         ],
         sub {
             my $params = shift;
@@ -270,9 +270,9 @@ Raisin - REST-like API micro-framework for Perl.
         };
 
         post params => [
-            required => ['name', $Raisin::Types::String],
-            required => ['password', $Raisin::Types::String],
-            optional => ['email', $Raisin::Types::String, undef, qr/.+\@.+/],
+            required => ['name', 'Raisin::Types::String'],
+            required => ['password', 'Raisin::Types::String'],
+            optional => ['email', 'Raisin::Types::String', undef, qr/.+\@.+/],
         ],
         sub {
             my $params = shift;
@@ -283,7 +283,7 @@ Raisin - REST-like API micro-framework for Perl.
             { success => 1 }
         };
 
-        route_param 'id' => $Raisin::Types::Integer,
+        route_param 'id' => 'Raisin::Types::Integer',
         sub {
             get sub {
                 my $params = shift;
@@ -312,7 +312,7 @@ Adds a route to application.
 
 Define a route parameter as a namespace C<route_param>.
 
-    route_param id => $Raisin::Types::Integer, sub { ... };
+    route_param id => 'Raisin::Types::Integer', sub { ... };
 
 =head2 delete, get, post, put
 
@@ -321,8 +321,8 @@ These are shortcuts to C<route> restricted to the corresponding HTTP method.
     get sub { 'GET' };
 
     get params => [
-        required => ['id', $Raisin::Types::Integer],
-        optional => ['key', $Raisin::Types::String],
+        required => ['id', 'Raisin::Types::Integer'],
+        optional => ['key', 'Raisin::Types::String'],
     ],
     sub { 'GET' };
 
@@ -464,8 +464,8 @@ Parameters can be C<required> and C<optional>. C<optional> parameters can have a
 default value.
 
     get params => [
-        required => ['name', $Raisin::Types::String],
-        optional => ['number', $Raisin::Types::Integer, 10],
+        required => ['name', 'Raisin::Types::String'],
+        optional => ['number', 'Raisin::Types::Integer', 10],
     ],
     sub {
         my $params = shift;
@@ -505,6 +505,10 @@ Here is built-in types
 
 =item *
 
+L<Raisin::Types::Float>
+
+=item *
+
 L<Raisin::Types::Integer>
 
 =item *
