@@ -23,7 +23,8 @@ sub _attr {
         $attr = sub {
             my ($self, $value) = @_;
             $self->{"_$name"} = $value if defined $value;
-            $self->{"_$name"} // $default;
+            $self->{"_$name"} = $default if $default;
+            $self->{"_$name"};
         };
     }
 
